@@ -224,7 +224,7 @@ page_list_selection_changed(GtkTreeSelection * sel, gpointer user_data)
     GtkTreePath *path;
     gint page;
     gchar *path_str;
-
+    
     path = gtk_tree_model_get_path(model, &iter);
     path_str = gtk_tree_path_to_string(path);
     page = atoi(path_str);      /* FIXME atoi is locale dependant */
@@ -232,9 +232,10 @@ page_list_selection_changed(GtkTreeSelection * sel, gpointer user_data)
     if(page >= 0)
       g_signal_emit(G_OBJECT(sidebar),
                     ggv_sidebar_signals[SET_PAGE_SIGNAL], 0, page);
-    if(NULL != sidebar->priv->checklist)
+    if(NULL != sidebar->priv->checklist) {
       gtk_tree_view_scroll_to_cell
         (GTK_TREE_VIEW(sidebar->priv->checklist), path, NULL, FALSE, 0.0, 0.0);
+    }
     gtk_tree_path_free(path);
   }
 }
@@ -298,9 +299,14 @@ ggv_sidebar_page_changed(GgvSidebar * sidebar, gint page)
   if(!gtk_tree_selection_path_is_selected(sel, path)) {
     gtk_tree_selection_select_path(sel, path);
   }
-  if(NULL != sidebar->priv->checklist)
-    gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(sidebar->priv->checklist),
-                                 path, NULL, FALSE, 0.0, 0.0);
+  if(NULL != sidebar->priv->checklist) {
+    GtkTreeIter iter;
+    if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(GTK_CHECK_LIST(sidebar->priv->checklist)->list_model),
+                                     &iter)) {
+      gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(sidebar->priv->checklist),
+                                   path, NULL, FALSE, 0.0, 0.0);
+    }
+  }
   gtk_tree_path_free(path);
 }
 
