@@ -162,16 +162,12 @@ printcmd_focus_out_event(GtkWidget * entry, GdkEventFocus * e,
 static void
 size_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 {
-  GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-
   gtk_gs_defaults_set_size(gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
 
 static void
 zoom_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 {
-  GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-
   gtk_gs_defaults_set_zoom_factor
     (ggv_zoom_levels[gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box))]);
 }
@@ -180,8 +176,6 @@ zoom_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 static void
 orientation_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 {
-  GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-
   gtk_gs_defaults_set_orientation
     (gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
@@ -190,8 +184,6 @@ orientation_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 static void
 unit_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 {
-  GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-
   ggv_unit_index = gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box));
   gconf_client_set_int(gconf_client, "/apps/ggv/coordinates/units",
                        ggv_unit_index, NULL);
@@ -200,8 +192,6 @@ unit_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 static void
 autofit_combo_box_changed(GtkWidget * combo_box, gpointer user_data)
 {
-  GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(user_data);
-
   gtk_gs_defaults_set_zoom_mode
     (gtk_combo_box_get_active(GTK_COMBO_BOX(combo_box)));
 }
@@ -519,19 +509,11 @@ ggv_prefs_dialog_response(GtkDialog * dlg, gint resp_id, gpointer user_data)
 GtkWidget *
 ggv_prefs_dialog_new()
 {
-  static const gchar *tbstyle_labels[] = {
-    N_("_Use GNOME defaults"),
-    N_("Show _both icons and text"),
-    N_("Show only _icons"),
-    N_("Show only t_ext")
-  };
-
   GgvPrefsDialog *dlg;
-  GtkWidget *widget, *vbox, *sep, *bbox;
-  GtkWidget *table, *label, *menu, *frame;
+  GtkWidget *widget;
+  GtkWidget *table, *label;
   gint i;
   GtkGSPaperSize *papersizes = gtk_gs_defaults_get_paper_sizes();
-  GSList *tbstyle_group = NULL;
   GtkAccelGroup *dlg_accel_group;
   GClosure *closure;
   GtkObject *adj;
